import { useEffect, useState } from "react";

import Step from "../Step";
import PlantList from "./PlantList";
import Stack from "@mui/material/Stack";
import Button from "@mui/material/Button";
import PlantRepository from "../../../repository/PlantRepository";
import { Typography, Box, Modal } from "@mui/material";
import resultsBackgroundImage from "../../../assets/img/stepBackgrounds/step6.jpg";
import staticText from "../../../assets/data/staticText.json";
import { useActivator } from "../../providers/ActivationProvider";
import { StepperFooter } from "../../providers/StepperProvider";

const RESULTS_DESCRIPTION = (
  <Typography>
    Please review the plant species list. It can be saved as a CSV file or
    appended to a planting plan guidebook. Additional information on each
    species can be obtained by entering the plant species name into the search
    box at{" "}
    <a href="https://inaturalist.nz" target="blank">
      inaturalist.nz
    </a>{" "}
    or in the "search flora" box at{" "}
    <a href="https://www.nzpcn.org.nz/" target="blank">
      www.nzpcn.org.nz
    </a>
    . Click the "Download PDF" button to create a planting plan guidebook
    specific to your project site.
  </Typography>
);

export default function ResultsStep(props) {
  const [plants, setPlants] = useState(null);
  const [showModal, setShowModal] = useState(true);
  const { key } = useActivator();

  const closeModal = () => setShowModal(false);

  useEffect(() => {
    PlantRepository.getFilteredPlants(key)
      .then((response) => {
        setPlants(response.status === 200 ? response.data : []);
      }).catch(e => {
        setPlants([]);
      });
  }, [key]);

  const getTableRows = () => {
    // null if unloaded, empty if loaded but no results
      return plants?.map((plant) => ({
          name: plant.display_name,
          growthForm: plant.display_growth_form,
          moisturePreferences: plant.moisture_preferences,
          plantTolerances: plant.plant_tolerances,
          ecosystemServices: plant.ecosystem_services,
          carbonSequestration: plant.carbon_sequestration,
          stage: plant.stage,
      })) ?? null;
  };

  const download = (response, fileType, fileName) => {
    const url = window.URL.createObjectURL(
      new Blob([response.data], { type: fileType })
    );
    const link = document.createElement("a");
    link.href = url;
    link.setAttribute("download", fileName);
    document.body.appendChild(link);
    link.click();
  };

  const downloadCSV = () => {
    PlantRepository.getPlantsCSV(key).then((response) => {
      download(response, "text/csv", "plants.csv");
    });
  };

  const downloadPDF = () => {
    PlantRepository.getPlantsPDF(key).then((response) => {
      download(response, "application/pdf", "planting_guide.pdf");
    });
  };

  const stepContent = (
    <div className="py-4">
      <Box
        sx={{
          display: "flex",
          justifyContent: "space-between",
          alignItems: "center",
        }}
        className="pb-4"
      >
        <Typography variant="h5">{staticText.steps.results.title}</Typography>
        <Stack spacing={2} direction="row" justifyContent="end">
          <Button variant="contained" onClick={() => downloadPDF()}>
            Download PDF
          </Button>
          <Button variant="contained" onClick={() => downloadCSV()}>
            Download CSV
          </Button>
        </Stack>
      </Box>
      <Typography
        variant="body2"
        sx={{ paddingRight: "100px", paddingBottom: "20px" }}
      >
        {RESULTS_DESCRIPTION}
      </Typography>
      <PlantList rows={getTableRows()} />
    </div>
  );

  return (
    <>
      <Step
        contentComponent={stepContent}
        backgroundImage={resultsBackgroundImage}
      />
      <StepperFooter />
      <Modal open={showModal} onClose={closeModal}>
        <Box sx={{
          position: 'absolute',
          top: '50%',
          left: '50%',
          transform: 'translate(-50%, -50%)',
          width: 400,
          bgcolor: 'background.paper',
          border: '2px solid #000',
          boxShadow: 24,
          color: 'white',
          p: 4,
        }}>
          <Typography variant="h5" component="h2">Questionnaire Complete</Typography>
          <Typography sx={{ mt: 2 }}>You have completed the questionnaire for your chosen habitat. If you have purchased a physical copy of the planting guide, it should arrive at your chosen delivery address in a number of business days.</Typography>
          <Typography sx={{ mt: 2 }}>You may now dismiss this popup to view a table of results. You are able to access this page at any time in future by supplying the activation key used at the start of this questionnaire.</Typography>
          <Box sx={{ display: 'flex', flexDirection: 'row' }}>
            <Box sx={{ flex: '1 1 auto' }} />
            <Button onClick={closeModal}>Close</Button>
          </Box>
        </Box>
      </Modal>
    </>
  );
}
